package com.jiuqi.util;

import java.text.DecimalFormat;
import java.util.HashMap;

/* loaded from: com_jiuqi_util.jar:com/jiuqi/util/Html.class */
public class Html {
    private static final String[] SYS_COLOR_NAMES = {"scrollbar", "background", "activecaption", "inactivecaption", "menu", "window", "windowframe", "menutext", "windowtext", "captiontext", "inactiveborder", "inactivecaption", "appworkspace", "highlight", "highlighttext", "buttonface", "buttonshadow", "graytext", "buttontext", "inactivecaption", "buttonhighlight", "threeddarkshadow", "threedhighlight", "infotext", "infobackground"};
    private static final int SYS_COLOR_MASK = -16777216;

    private Html() {
    }

    public static String getHtmlColor(int colorValue) {
        String returnStr;
        if (colorValue < 0) {
            returnStr = getSystemColor(colorValue);
        } else {
            returnStr = "#" + repairLength(Integer.toHexString(BGR2RGB(colorValue)));
        }
        return returnStr;
    }

    public static int BGR2RGB(int color) {
        if (color < 0) {
            return color;
        }
        int red = (color & 255) << 16;
        int blue = (color & 16711680) >> 16;
        int green = color & 65280;
        return red | blue | green;
    }

    private static String repairLength(String colorStr) {
        if (colorStr == null) {
            return "000000";
        }
        if (colorStr.length() == 6) {
            return colorStr;
        }
        StringBuffer buffer = new StringBuffer(colorStr);
        while (buffer.length() < 6) {
            buffer.insert(0, '0');
        }
        return buffer.toString();
    }

    public static String getSystemColor(int intColor) {
        int colorValue;
        return ((intColor & SYS_COLOR_MASK) == SYS_COLOR_MASK && (colorValue = intColor & 16777215) < SYS_COLOR_NAMES.length) ? SYS_COLOR_NAMES[colorValue] : "";
    }

    public static String strToHtml(String instring) {
        int lIndex = 0;
        if (instring == null) {
            return "";
        }
        StringBuffer lStrbuff = new StringBuffer(instring);
        while (lIndex < lStrbuff.length()) {
            lStrbuff.charAt(lIndex);
            char lChar = lStrbuff.charAt(lIndex);
            if (lChar == '\"') {
                lStrbuff.replace(lIndex, lIndex + 1, "&#34;");
                lIndex += 5;
            } else if (lChar == '&') {
                lStrbuff.replace(lIndex, lIndex + 1, "&amp;");
                lIndex += 5;
            } else if (lChar == '<') {
                lStrbuff.replace(lIndex, lIndex + 1, "&lt;");
                lIndex += 4;
            } else if (lChar == '>') {
                lStrbuff.replace(lIndex, lIndex + 1, "&gt;");
                lIndex += 4;
            } else if (lChar == ' ') {
                lStrbuff.replace(lIndex, lIndex + 1, "&nbsp;");
                lIndex += 6;
            } else {
                lIndex++;
            }
        }
        return lStrbuff.toString();
    }

    public static String encodeText(String inString) {
        if (inString == null) {
            return "";
        }
        int lIndex = 0;
        char endChar = 0;
        StringBuffer outString = new StringBuffer(inString);
        while (lIndex < outString.length()) {
            char lChar = outString.charAt(lIndex);
            if (lIndex + 1 < outString.length()) {
                endChar = outString.charAt(lIndex + 1);
            }
            if (lChar == '&') {
                outString.replace(lIndex, lIndex + 1, "&amp;");
                lIndex += 5;
            } else if (lChar == '<') {
                outString.replace(lIndex, lIndex + 1, "&lt;");
                lIndex += 4;
            } else if (lChar == '>') {
                outString.replace(lIndex, lIndex + 1, "&gt;");
                lIndex += 4;
            } else {
                char lChar2 = outString.charAt(lIndex);
                if (lChar2 == '\"') {
                    outString.replace(lIndex, lIndex + 1, "&#34;");
                    lIndex += 5;
                } else if (lChar2 == '\r' && endChar == '\n') {
                    outString.replace(lIndex, lIndex + 2, "<br>");
                    lIndex += 4;
                } else if (lChar2 == ' ') {
                    outString.replace(lIndex, lIndex + 1, "&nbsp;");
                    lIndex += 6;
                } else {
                    lIndex++;
                }
            }
        }
        return outString.toString();
    }

    public static String Double2Str(double value) {
        DecimalFormat df = new DecimalFormat("#.#");
        return df.format(value);
    }

    public static String fmtDouble(double value) {
        DecimalFormat df = new DecimalFormat("0.0000");
        return df.format(value);
    }

    public static String encodeHashMap(HashMap hashMap) {
        if (hashMap == null || hashMap.isEmpty()) {
            return null;
        }
        StringBuffer result = new StringBuffer();
        for (Object key : hashMap.keySet()) {
            result.append(key);
            result.append(':');
            Object value = hashMap.get(key);
            if (value != null) {
                result.append(value);
            }
            result.append(';');
        }
        if (result.length() > 0) {
            result.deleteCharAt(result.length() - 1);
        }
        return result.toString();
    }

    public static HashMap decodeHashMap(String s) {
        String[] entries;
        if (StringUtils.isEmpty(s)) {
            return null;
        }
        HashMap result = new HashMap();
        String[] maps = s.split(StringHelper.semicolon);
        if (maps == null) {
            return result;
        }
        for (int i = 0; i < maps.length; i++) {
            if (!StringUtils.isEmpty(maps[i]) && (entries = maps[i].split(":")) != null) {
                if (entries.length == 1) {
                    result.put(entries[0], null);
                } else if (entries.length == 2) {
                    result.put(entries[0], entries[1]);
                }
            }
        }
        return result;
    }
}
